Update your application's privacy policy to explicitly state if and how user photos, videos, or other media files are accessed or collected. Clearly describe the purposes for this access or collection, how the media is used, processed, stored, and its retention period. Ensure that clear user consent is obtained before accessing user media and that users have control over these permissions.